// File: StateDBAccess.java
// Test Oracle Database with States file 

import java.io.*;
import java.sql.*;
import java.text.DecimalFormat;

public class StateDBAccess {

  private static final String USERNAME = "spiegel";
  private static final String PASSWORD = "legeips";

 // Output name, cap, & pop of states returned from a query
 public static void outputQueryResults(ResultSet data)
                                              throws java.sql.SQLException
 // Won't use try..catch here
 {System.out.println("State Name     State Capital    Population");
  // Let's print what we got; First, some formats
  DecimalFormat popForm=new DecimalFormat("    0000");
  while (data.next()) {// once for each line in the database
      StringBuffer NameBuf, CapBuf;
      // ResultSet has functions to obtain elements; we need for String & int
      // Note we could use field # insteasd of "Name"; also null terminate. Why?
      // NameBuf = new StringBuffer(data.getString("sName") + "\0");
      NameBuf = new StringBuffer(data.getString("sName"));
      // Expand to 15 characters, left justified
      NameBuf.setLength(15);

      // Same for the capital
      // CapBuf = new StringBuffer(data.getString("sCap") + '\0');
      CapBuf = new StringBuffer(data.getString("sCap"));
      // Expand to 15 characters, left justified
      CapBuf.setLength(15);

      // Ready to output; Note use of popForm
      System.out.println(NameBuf + CapBuf.toString() +
                         popForm.format(data.getInt("sPop")));
  }
 }

 // Print the States database
 public static void printData(Statement stmnt)
 {try {
  // Issue a query so we can output a subset of the database contents
     // The query will obtain all states' info as listed, and
     //  also asks that the data be ordered
     ResultSet data=stmnt.executeQuery("SELECT sName, sPop, sCap FROM States"+
                                                            " ORDER BY sName");
     outputQueryResults(data);
   }
   catch (Exception e) {
     e.printStackTrace();
   }
 }

 // Find all states in a designated population range
 //  Use to demonstrate a PreparedStatement with variables
 public static void findByPop(Statement stmnt,Connection con)
 {int low, high;
  BufferedReader DataInput=new BufferedReader(new InputStreamReader(System.in));
  // Must set up a query in a String, since we are using variable values
  // Let's use a PreparedStatement
  String query =
    "SELECT sName, sPop, sCap FROM States WHERE sPop BETWEEN ? AND ? "+
							" ORDER BY sName";
  try {
    PreparedStatement qStmnt=con.prepareStatement(query);
    System.out.println("\nList States within a Range of Population");
    System.out.print("Enter Low Bound. Enter -1 to quit >");
    low = Integer.parseInt(DataInput.readLine());
    while (low >=0) {
      System.out.print("Enter High Bound >");
      high = Integer.parseInt(DataInput.readLine());
      // Set the values in the PreparedStatement
      qStmnt.setInt(1,low);
      qStmnt.setInt(2,high);
      // Set up for query
      ResultSet res = qStmnt.executeQuery();
      System.out.println("States with Population Between " + low + " & " +
                         high);
      outputQueryResults(res);
      System.out.print("Enter Low Bound. Enter -1 to quit >");
      low = Integer.parseInt(DataInput.readLine());
      res.close(); // Must close before we can change query parameters
    }
  }
  catch (Exception e) {
    e.printStackTrace();
  }
 }

 // User can update one state's capital
 public static void updateCap(Statement stmnt)
 {BufferedReader DataInput=new BufferedReader(new InputStreamReader(System.in));
  String StateName="";
  try {
    System.out.println("\nEnter a State and Update its Capital!");
    System.out.print("Enter State to Update >");
    StateName = DataInput.readLine().toUpperCase();
    ResultSet out = stmnt.executeQuery("SELECT sName FROM States WHERE sName='"
                                       + StateName + "' ");
  }
  catch (Exception e) {
    e.printStackTrace();
  }
  int res;
  try {
    System.out.print("Enter New Capital of "+StateName+" >");
    String NewCap=DataInput.readLine().toUpperCase();
    String update=
        "UPDATE States SET sCap='"+NewCap+"' WHERE sName='"+ StateName +"' ";
    // Execute an *UPDATE*, not a query
    res = stmnt.executeUpdate(update);
    // Next statement won't get done if state not found; why not?
    System.out.println("Success: Received "+res+" results");
    stmnt.close();
  }
  catch (Exception e) {
    System.out.println(e);
  }
 }

 public static void main(String[] args) throws java.io.IOException
 {// Set up JDBC stuff
  Statement stmnt;
  try {
    Connection con = new OracleConnection().getConnection( USERNAME, PASSWORD);
    stmnt=con.createStatement();
    stmnt=con.createStatement();
    printData(stmnt);
    findByPop(stmnt,con);
    updateCap(stmnt);
  }
  catch (Exception e) {
    e.printStackTrace();
  }

 }

}  // class

